@@ -81,6 +81,16 @@ sub dashboard {
     };
 }
 
+=head2 failed_jobs
+
+Search failed jobs
+
+=cut
+
+sub failed_jobs {
+    return {};
+}
+
 =head2 job
 
 Find a job by id
@@ -93,6 +103,36 @@ sub job {
     return $self->minion->job($id);
 }
 
+=head2 job_runtime_metrics
+
+Job runtime metrics
+
+=cut
+
+sub job_runtime_metrics {
+    return [];
+}
+
+=head2 job_throughput_metrics
+
+Job throughput metrics
+
+=cut
+
+sub job_throughput_metrics {
+    return [];
+}
+
+=head2 jobs
+
+Search jobs
+
+=cut
+
+sub jobs {
+    return {};
+}
+
 =head2 limit
 
 Set the limit and return current instance
@@ -159,6 +199,16 @@ sub tags {
     return $self;
 }
 
+=head2 unique_jobs
+
+Search the list of unique jobs
+
+=cut
+
+sub unique_jobs {
+    return {};
+}
+
 =head2 when
 
 Add where condition when first param is true
@@ -192,6 +242,36 @@ sub where {
     return $self;
 }
 
+=head2 worker
+
+Find a worker by id
+
+=cut
+
+sub worker {
+    return {};
+}
+
+=head2 worker_waittime_metrics
+
+Worker waittime metrics
+
+=cut
+
+sub worker_waittime_metrics {
+    return [];
+}
+
+=head2 worker_throughput_metrics
+
+Worker throughput metrics
+
+=cut
+
+sub worker_throughput_metrics {
+    return [];
+}
+
 =head2 workers
 
 Get workers information
